@@ -19,6 +19,31 @@ from ipywidgets import Box, DOMWidget, CoreWidget, Text, Label, Textarea, \
 from ipywidgets.widgets.trait_types import InstanceDict
 from traitlets import Int, Unicode, Dict, Bool, Union, List
 from IPython.display import display
+import types
+
+
+class EasyFormComponent:
+    def __init__(self):
+        self.onInitListeners = list()
+        self.onChangeListeners = list()
+
+    def onInit(self, f):
+        if f is not None and isinstance(f, types.FunctionType):
+            self.onInitListeners.append(f)
+        return self
+
+    def onChange(self, f):
+        if f is not None and isinstance(f, types.FunctionType):
+            self.onChangeListeners.append(f)
+        return self
+
+    def fireInit(self):
+        for f in self.onInitListeners:
+            f()
+
+    def fireChanged(self, x=None):
+        for f in self.onChangeListeners:
+            f(x)
 
 
 class BeakerxLayout(Layout):
@@ -63,6 +88,7 @@ class BeakerxDOMWidget(DOMWidget):
 class BeakerxBox(Box):
     def __init__(self, **kwargs):
         super(BeakerxBox, self).__init__(**kwargs)
+        self.components = dict()
 
     _view_module = Unicode('beakerx').tag(sync=True)
     _model_module = Unicode('beakerx').tag(sync=True)
@@ -80,12 +106,15 @@ class BeakerxBox(Box):
             },
             'method': 'display_data'
         }
+        for component in self.components:
+            self.components[component].fireInit()
+
         display(data, raw=True)
 
         self._handle_displayed(**kwargs)
 
 
-class BeakerxTextArea(Textarea):
+class BeakerxTextArea(Textarea, EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxTextArea, self).__init__(**kwargs)
 
@@ -100,9 +129,13 @@ class BeakerxTextArea(Textarea):
     style = None
 
 
-class BeakerxText(Text):
+class BeakerxText(Text, EasyFormComponent):
+    def on_value_change(self, change):
+        self.fireChanged(change['new'])
+
     def __init__(self, **kwargs):
         super(BeakerxText, self).__init__(**kwargs)
+        self.observe(self.on_value_change, names='value')
 
     _view_module = Unicode('beakerx').tag(sync=True)
     _model_module = Unicode('beakerx').tag(sync=True)
@@ -114,7 +147,7 @@ class BeakerxText(Text):
     style = None
 
 
-class BeakerxHTML(HTML):
+class BeakerxHTML(HTML, EasyFormComponent):
     def __init__(self, *args, **kwargs):
         super(BeakerxHTML, self).__init__(**kwargs)
         if len(args) > 0:
@@ -127,7 +160,7 @@ class BeakerxHTML(HTML):
     style = None
 
 
-class BeakerxHTMLPre(HTML):
+class BeakerxHTMLPre(HTML, EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxHTMLPre, self).__init__(**kwargs)
 
@@ -142,7 +175,7 @@ class BeakerxHTMLPre(HTML):
     style = None
 
 
-class BeakerxButton(Button):
+class BeakerxButton(Button, EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxButton, self).__init__(**kwargs)
 
@@ -155,12 +188,11 @@ class BeakerxButton(Button):
     layout = InstanceDict(BeakerxLayout).tag(sync=True, **widget_serialization)
     style = None
 
-
     def actionPerformed(self, *args, **kwargs):
         pass
 
 
-class BeakerxComboBox(Dropdown):
+class BeakerxComboBox(Dropdown, EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxComboBox, self).__init__(**kwargs)
 
@@ -181,7 +213,7 @@ class BeakerxComboBox(Dropdown):
         super(BeakerxComboBox, self)._handle_msg(msg)
 
 
-class BeakerxCheckbox(Checkbox):
+class BeakerxCheckbox(Checkbox, EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxCheckbox, self).__init__(**kwargs)
 
@@ -194,14 +226,18 @@ class BeakerxCheckbox(Checkbox):
     style = None
 
 
-class BeakerxCheckboxGroup():
+class BeakerxCheckboxGroup(EasyFormComponent):
+    def __init__(self, **kwargs):
+        super(BeakerxCheckboxGroup, self).__init__(**kwargs)
+
     children = []
     value = property(lambda self: [item.description for item in self.children if item.value])
 
     def addChildren(self, children):
         self.children.append(children)
 
-class BeakerxLabel(Label):
+
+class BeakerxLabel(Label, EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxLabel, self).__init__(**kwargs)
 
@@ -284,3 +320,42 @@ class Tab(SelectionContainer):
 
     def __init__(self, childrens, labels):
         super(Tab, self).__init__(childrens, labels)
+
+
+class SelectMultipleWithRows(SelectMultiple, EasyFormComponent):
+    def __init__(self, **kwargs):
+        super(SelectMultipleWithRows, self).__init__(**kwargs)
+
+    _view_module = Unicode('beakerx').tag(sync=True)
+    _model_module = Unicode('beakerx').tag(sync=True)
+    size = Int(5, help="The number of rows to display.").tag(sync=True)
+
+
+class SelectMultipleSingle(Select, EasyFormComponent):
+    def __init__(self, **kwargs):
+        super(SelectMultipleSingle, self).__init__(**kwargs)
+
+    _view_name = Unicode('SelectMultipleSingleView').tag(sync=True)
+    _model_name = Unicode('SelectMultipleSingleModel').tag(sync=True)
+    _view_module = Unicode('beakerx').tag(sync=True)
+    _model_module = Unicode('beakerx').tag(sync=True)
+    size = Int(5, help="The number of rows to display.").tag(sync=True)
+
+
+class RadioButtons(RadioButtons, EasyFormComponent):
+    def __init__(self, **kwargs):
+        super(RadioButtons, self).__init__(**kwargs)
+
+
+class DatePicker(BeakerxDOMWidget, EasyFormComponent):
+    def __init__(self, value=None, **kwargs):
+        if value is not None:
+            kwargs['value'] = value
+        super(DatePicker, self).__init__(**kwargs)
+
+    _view_name = Unicode('DatePickerView').tag(sync=True)
+    _model_name = Unicode('DatePickerModel').tag(sync=True)
+    showTime = Bool(default_value=False,
+                    help="Enable or disable user changes.").tag(sync=True)
+    value = Unicode(default_value="").tag(sync=True)
+    description = Unicode(default_value="").tag(sync=True)
