@@ -18,7 +18,7 @@ from beakerx.utils import *
 from beakerx.tabledisplay.tableitems import *
 import math
 import numpy
-from pandas import DataFrame
+from pandas import DataFrame, RangeIndex, MultiIndex
 
 
 class Table(BaseObject):
@@ -28,6 +28,7 @@ class Table(BaseObject):
         self.types = []
         types_map = dict()
         self.columnNames = []
+        self.hasIndex = None
         if isinstance(args[0], DataFrame):
             self.convert_from_pandas(args, types_map)
         elif isinstance(args[0], dict):
@@ -36,7 +37,6 @@ class Table(BaseObject):
             self.convert_from_list(args, types_map)
 
         self.headersVertical = False
-        self.hasIndex = None
         self.headerFontSize = None
         self.contextMenuItems = []
         self.alignmentForType = {}
@@ -89,20 +89,33 @@ class Table(BaseObject):
 
     def convert_from_pandas(self, args, types_map):
         self.columnNames = args[0].columns.tolist()
+        if args[0].index.name is not None and args[0].index.name in self.columnNames:
+            self.columnNames.remove(args[0].index.name)
+
         for column in self.columnNames:
             column_type = self.convert_type(args[0].dtypes[column].name,
-                                            args[0][column][0])
+                                            args[0][column].get_values()[0])
             self.types.append(column_type)
             types_map[column] = column_type
         for index in range(len(args[0])):
             row = []
             for columnName in self.columnNames:
-                value = args[0][columnName][index]
+                value = args[0][columnName].get_values()[index]
                 value_type = types_map.get(columnName)
 
                 row.append(self.convert_value(value, value_type))
+            if not isinstance(args[0].index, RangeIndex):
+                row[:0] = [self.convert_value(args[0].index.get_values()[index], type(args[0].index.get_values()[index]))]
             self.values.append(row)
 
+        if not isinstance(args[0].index, RangeIndex):
+            self.hasIndex = "true"
+            if isinstance(args[0].index, MultiIndex):
+                self.columnNames[:0] = [', '.join(args[0].index.names)]
+            else:
+                self.columnNames[:0] = [args[0].index.name]
+            self.types[:0] = [self.convert_type("", args[0][column].get_values()[0])]
+
     @staticmethod
     def convert_value(value, value_type):
         if value_type == "time":
@@ -142,11 +155,10 @@ class Table(BaseObject):
                 return "integer"
         if object_type == "uint64":
             return "int64"
-        if isinstance(value, str):
-            return "string"
         if is_date(value):
             return "time"
-
+        if isinstance(value, str):
+            return "string"
         return "string"
 
 
